@@ -8,8 +8,10 @@ pyslha is a parser/writer module for particle physics SUSY Les Houches Accord
 use the interface, e.g. for conversion to and from the legacy ISAWIG format, or
 to plot the mass spectrum and decay chains.
 
-The current release supports SLHA version 1. Assistance with supporting version
-2 will be gladly accepted!
+The current release supports SLHA version 1, and as far as we're aware is also
+fully compatible with SLHA2: the block structures are read and accessed
+completely generically. If you have any problems with SLHA2, please provide an
+example input file and we'll investigate.
 
 The plotting script provides output in PDF, EPS and PNG via LaTeX and the TikZ
 graphics package, and as LaTeX/TikZ source for direct embedding into documents or
@@ -18,12 +20,11 @@ user-tweaking of the generated output.
 TODOs:
  * Identify HERWIG decay matrix element to use in ISAWIG
  * Split writeSLHA into writeSLHA{Blocks,Decays}
- * Handle SLHA2
  * Handle RPV SUSY in ISAWIG
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.2.3"
+__version__ = "1.2.4"
 
 
 def _autotype(var):
